from django.apps import AppConfig


class DjoptimizelyConfig(AppConfig):
    name = 'djoptimizely'
